@@ -46,8 +46,8 @@ module.exports = generators.Base.extend({
         done();
       }.bind(this));
     },
-    askForRoutes: self.utils.routes.ask,
-    askForModels: self.utils.models.ask,
+    askForRoutes: function() { ionicUtils.routes.ask(this) },
+    askForModels: function() { ionicUtils.models.ask(this) },
     /*
     askForAnalytics: function askForAnalytics() {
       var done = this.async();
@@ -187,8 +187,8 @@ module.exports = generators.Base.extend({
         done();
       }.bind(this));
     },
-    installModels: this.utils.models.install,
-    installRoutes: this.utils.routes.install,
+    installModels: function installModels() { ionicUtils.models.install(this) },
+    installRoutes: function installRoutes() { ionicUtils.routes.install(this) },
     installAuthProvider: function installAuthProvider() {
       console.log('installAuthProvider');
       console.log(this.auth);
