@@ -1,14 +1,16 @@
 
-createIndexHtml: function createIndexHtml(self, provider) {
-  var file = this.readFileAsString(path.join(__dirname, '../scripts/' + provider + '.js'))
-  file.replace(/{{APP_NAME}}/g, self.appName);
-  this.write(path.join(this.appPath, provider+'Service.js'), file);
+var path = require('path');
+
+var createService = function(self, provider) {
+  var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/' + provider + 'AuthService.js'))
+  file = file.replace("{{APP_NAME}}", self.appName);    
+  self.write(path.join(self.appPath, provider+'Service.js'), file);
 }
 
 module.exports = {
   prompts: [{
     type: 'checkbox',
-    name: 'authentification provider',
+    name: 'providers',
     message: 'Which Authentification provider would you like to include?',
     choices: [{
       value: 'twitter',
@@ -30,7 +32,8 @@ module.exports = {
   install: function(self, choices, done) {
     var promises = [];
     for (var i = choices.length - 1; i >= 0; i--) {
-      console.log(choices[i]);
+      console.log('Choice:' + choices[i]);
+      createService(self, choices[i]);
     };
     done();
   },
