@@ -14,7 +14,7 @@ var showModelPrompt = function(self, done) {
     } else {
       self.models.push(props.model);
       console.log(self.models);
-      addModelPrompt(self, done);
+      showModelPrompt(self, done);
     }
   }.bind(self));  
 }
