@@ -6,7 +6,7 @@ var showRouteAbstractPrompt = function(self, routeObj, done) {
   self.prompt([{
     type:'confirm',
     name:'routeAbstract',
-    message:'Is ' + routeObj.state + ' state abstract ?',
+    message:'  Is ' + routeObj.state + ' state abstract ?',
     default: false
   }], function(response) {
     routeObj.abstract = response.routeAbstract;
@@ -23,16 +23,14 @@ var showRouteUrlPrompt = function(self, routeObj, done) {
   self.prompt([{
     type:'input',
     name:'routeUrl',
-    message:'Enter the route URL for ' + routeObj.state + ' or \"done\" if you are',
+    message:'  Enter the route URL for ' + routeObj.state + ' or \"done\" if you are',
     default: routeObj.state
   }], function(response) {
       if ( response.routeState == 'done') {
         done();
     } else {
       routeObj.url = response.routeUrl;
-      self.routes.push(routeObj);
-      console.log('Current routes: ' + self.routes);
-      showRouteAbstractPrompt(self, routeObj, showRouteStatePrompt, done);
+      showRouteAbstractPrompt(self, routeObj, done);
     }
   });
 }
@@ -41,9 +39,10 @@ var showRouteStatePrompt = function(self, done) {
   self.prompt([{
     type:'input',
     name:'routeState',
-    message:'Enter the route state or \"done\" if you are'
+    message:' Enter the route state or \"done\" if you are'
   }], function(response) {
       if ( response.routeState == 'done') {
+        console.log('DONE!!');
         done();
     } else {
       routeObj.state = response.routeState;
@@ -52,7 +51,7 @@ var showRouteStatePrompt = function(self, done) {
   });
 }
 
-var generateConfigRoute = function(configRoutes, route) {
+var generateConfigRoute = function(self, configRoutes, route) {
   var ctrl = route.state + 'Ctrl.js';
   var view = route.state + '.html';
   configRoutes += 
@@ -64,6 +63,7 @@ var generateConfigRoute = function(configRoutes, route) {
     "})";
   var ctrlFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/ctrl.js'))
   ctrlFile = ctrlFile.replace("{{APP_NAME}}", self.appName);
+  ctrlFile = ctrlFile.replace("{{CTRL_NAME}}", route.state + 'Ctrl.js');
   self.write(path.join(self.appPath, ctrl), ctrlFile);
   self.copy('../templates/views/empty.js', view);
 }
@@ -79,7 +79,6 @@ module.exports = {
       if (response.routes == true) {
         self.routes = [];
         showRouteStatePrompt(self, done);
-        addModelPrompt(addModelPrompt, done);
       } else {
         done();
       }
@@ -94,7 +93,7 @@ module.exports = {
     }
     for (var i = routes.length - 1; i >= 0; i--) {
       console.log('Installing route:' + routes[i].state);
-      createService(configRoutes, routes[i]);
+      generateConfigRoute(self, configRoutes, routes[i]);
     };
     var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/config.js'))
     file = file.replace("{{APP_NAME}}", self.appName);
